@@ -23,16 +23,14 @@ def includeme(config):
     settings = config.registry.settings
 
     for key, default in (
-        ('audience', None),
         ('verifier_url', 'https://verifier.login.persona.org/verify'),
         ):
 
         option = 'persona_%s' % key
         settings[option] = read_setting_from_env(settings, option, default)
 
-    if settings['persona_audience']:
-        config.add_route('persona_login', '/persona/login')
-        config.add_view('.views.persona_login',
-                        route_name='persona_login', renderer='string')
+    config.add_route('persona_login', '/persona/login')
+    config.add_view('.views.persona_login',
+                    route_name='persona_login', renderer='string')
 
-        config.add_identity_provider('persona')
+    config.add_identity_provider('persona')
