@@ -115,6 +115,7 @@ class ViewTests(TestCase):
         self.assertEqual(user['email'], 'john@example.com')
         self.assertEqual(user['email_verified'], True)
         self.assertEqual(user['authorized_apps'], [])
+        self.assertEqual(user['send_passwords_periodically'], False)
 
         # the next_url and user_info keys are cleared at this point
         self.add_to_session({
@@ -147,6 +148,7 @@ class ViewTests(TestCase):
         self.assertEqual(user['email'], '')
         self.assertEqual(user['email_verified'], False)
         self.assertEqual(user['authorized_apps'], [])
+        self.assertEqual(user['send_passwords_periodically'], False)
 
         # the next_url and user_info keys are cleared at this point
         self.add_to_session({
@@ -181,6 +183,7 @@ class ViewTests(TestCase):
         self.assertEqual(user['email'], '')
         self.assertEqual(user['email_verified'], False)
         self.assertEqual(user['authorized_apps'], [])
+        self.assertEqual(user['send_passwords_periodically'], False)
 
         # check that the email was sent
         res.request.registry = self.testapp.app.registry
@@ -224,6 +227,7 @@ class ViewTests(TestCase):
         self.assertEqual(user['email_verified'], False)
         self.assertEqual(user['authorized_apps'], [])
         self.assertEqual(user[USER_ATTR], True)
+        self.assertEqual(user['send_passwords_periodically'], False)
 
         # the next_url and user_info keys are cleared at this point
         self.add_to_session({
@@ -381,18 +385,21 @@ class ViewTests(TestCase):
 
         res = self.testapp.get('/preferences')
         self.assertEqual(res.status, '200 OK')
-        res.mustcontain('Preferences', 'Allow statistics cookie',
+        res.mustcontain('Preferences',
+                        'Allow statistics cookie',
                         'Save changes')
 
         res = self.testapp.post('/preferences', {
                 'submit': 'Save changes',
                 'allow_google_analytics': 'true',
+                'send_passwords_periodically': 'false',
                 })
         self.assertEqual(res.status, '302 Found')
         self.assertEqual(res.location, 'http://localhost/preferences')
         # check that the user has changed
         new_user = self.db.users.find_one({'_id': user_id})
         self.assertEqual(new_user['allow_google_analytics'], True)
+        self.assertEqual(new_user['send_passwords_periodically'], False)
 
         # make the form fail
         with patch('deform.Form.validate') as fake:
@@ -408,6 +415,7 @@ class ViewTests(TestCase):
             res = self.testapp.post('/preferences', {
                     'submit': 'Save changes',
                     'allow_google_analytics': 'true',
+                    'send_passwords_periodically': 'false',
                     })
             self.assertEqual(res.status, '200 OK')
             res.mustcontain('There were an error while saving your changes')
